#ifndef _EFL_VG_GRADIENT_LINEAR_EO_H_
#define _EFL_VG_GRADIENT_LINEAR_EO_H_

#ifndef _EFL_VG_GRADIENT_LINEAR_EO_CLASS_TYPE
#define _EFL_VG_GRADIENT_LINEAR_EO_CLASS_TYPE

typedef Eo Efl_VG_Gradient_Linear;

#endif

#ifndef _EFL_VG_GRADIENT_LINEAR_EO_TYPES
#define _EFL_VG_GRADIENT_LINEAR_EO_TYPES


#endif
/** Efl vector graphics gradient linear class
 *
 * @ingroup Efl_VG_Gradient_Linear
 */
#define EFL_VG_GRADIENT_LINEAR_CLASS efl_vg_gradient_linear_class_get()

EWAPI const Efl_Class *efl_vg_gradient_linear_class_get(void);

#endif
